ConnectivityScreenWrapper class

Inheritance

Constructors

ConnectivityScreenWrapper({Key? key, Widget? child, Color? color, Decoration? decoration, String? message, TextStyle? messageStyle, double? height, TextAlign? textAlign, Duration? duration, PositionOnScreen positionOnScreen = PositionOnScreen.BOTTOM, bool disableInteraction = false, Widget? disableWidget})
const

Properties

child → Widget?
The child contained by the ConnectivityScreenWrapper.
final
color → Color?
The color to paint behind the child.
final
decoration → Decoration?
The decoration to paint behind the child.
final
disableInteraction → bool
Disable the user interaction with child widget
final
disableWidget → Widget?
Disable the user interaction with child widget
final
duration → Duration?
How to align the offline widget.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
widget height.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message → String?
Disconnected message.
final
messageStyle → TextStyle?
If non-null, the style to use for this text.
final
positionOnScreen → PositionOnScreen
How to align the offline widget.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → TextAlign?
How the text should be aligned horizontally.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited