ConnectivityWrapper class

Properties

addresses ↔ List<AddressCheckOptions>
getter/setter pair
checkInterval ↔ Duration
getter/setter pair
connectionStatus → Future<ConnectivityStatus>
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
no setter
isActivelyChecking → bool
no setter
isConnected → Future<bool>
no setter
lastStatus → ConnectivityStatus?
no setter
lastTryResults → List<AddressCheckResult>
no setter
onStatusChange → Stream<ConnectivityStatus>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isHostReachable(AddressCheckOptions options) → Future<AddressCheckResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → ConnectivityWrapper
final